OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Закладки",
    "You bookmarked \"%s\"" : "Ви додали закладку до \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s додав(-ла) закладку до \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Хтось додав(-ла) закладку до \"%s\"",
    "You deleted \"%s\"" : "Ви вилучили \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s вилучив(-ла) \"%2$s\"",
    "Someone deleted \"%s\"" : "Хтось вилучив(-ла) \"%s\"",
    "You created folder \"%s\"" : "Ви створили каталог \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s створив(-ла) каталог \"%2$s\"",
    "Someone created folder \"%s\"" : "Хтось створив(-ла) каталог \"%s\"",
    "You moved folder \"%s\"" : "Ви перемістили каталог \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s перемістив(-ла) каталог \"%2$s\"",
    "Someone moved folder \"%s\"" : "Хтось перемістив(-ла) каталог \"%s\"",
    "You deleted folder \"%s\"" : "Ви вилучили каталог \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s вилучив(-ла) каталог \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Хось вилучив(-ла) каталог \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Ви поділилися каталогом \"%1$s\" із %2$s",
    "You shared folder \"%s\" with someone" : "Ви поділилися каталогом \"%s\" із кимось",
    "%1$s shared folder \"%2$s\" with you" : "%1$s надав(-ла) вам доступ до каталогу \"%2$s\"",
    "Someone shared folder \"%s\" with you" : "Хтось поділився каталогом \"%s\" з вами",
    "You unshared folder \"%1$s\" with %2$s" : "Ви прибрали доступ до каталогу \"%1$s\" для %2$s",
    "You unshared folder \"%s\" with someone" : "Ви прибрали доступ до каталоу \"%s\" для всіх",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s прибрав(-ла) доступ до каталогу \"%2$s\" для вас",
    "Someone unshared folder \"%s\" with you" : "Хтось прибрав доступ до каталогу \"%s\" для вас",
    "No file provided for import" : "Відсутній файл для імпорту",
    "Failed to upload file" : "Не вдалося завантажити файл",
    "Unsupported file type for import: " : "Цей тип файлу не підтримується для імпорту:",
    "Bookmarks shared by %s" : "Закладки, якими поділив(-ла)ся %s",
    "Frequent bookmarks" : "Часті закладки",
    "Recent bookmarks" : "Останні закладки",
    "Bookmark" : "Закладка",
    "Bookmark deleted" : "Закладку вилучено",
    "Bookmark created" : "Закладку створено",
    "Bookmark moved" : "Закладку переміщено",
    "Bookmark updated" : "Закладку оновлено",
    "Create bookmark" : "Створити закладку",
    "Takes a link and adds it to your collection of bookmarks." : "Отримує посилання та додає до вашої колекції закладок.",
    "Bookmarks Backups" : "Резервні копії закладок",
    "Collect and manage bookmarks, synced with all your devices" : "Збирайте та впорядковуйте закладки, які синхронізуються зі всіма вашими пристроями",
    "Do you really want to delete this bookmark?" : "Дічно вилучити цю закладку?",
    "Link copied to clipboard" : "Посилання скопійовано в буфер обміну",
    "Enter new title" : "Зазначте новий заголовок",
    "Select bookmark" : "Вибрати закладку",
    "You have never clicked this link" : "Ви раніше не переходили за цим посиланням",
    "You have clicked this link {count} times" : "Ви переходили за цим посиланням {count} раз(-ів)",
    "Details" : "Деталі",
    "Rename" : "Перейменувати",
    "Copy link" : "Копіювати посилання",
    "Move" : "Перемістити",
    "Add to folders" : "Додати до каталогу",
    "Put bookmark into trash bin" : "Вилучити закладку",
    "Restore bookmark" : "Відновити закладку",
    "Delete bookmark permanently" : "Вилучити закладку назавжди",
    "Content pending" : "Отримання вмісту",
    "This content is being downloaded for offline use. Please check back later." : "Вміст звантажується для використання в автономному режимі. Будь ласка, перевірте пізніше.",
    "Bookmarked {time} ago" : "Закладку створено {time} назад",
    "Bookmarked on {date}" : "Закладку створено {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Тут розташовано вилучені об'єкти, які буде вилучено остаточно через 2 місяці.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Закладки на файли в мережі, такі як світлини або файли PDF, буде автоматично збережено до ваших файлів у хмарі Nextcloud. Таким чином ви зможете завжди їх знаходити, навіть якщо посилання будуть недоступні.",
    "Searching in the current folder only." : "Шукати тільки в поточному каталозі.",
    "Repeat search in all folders" : "Повторити пошук у всіх каталогах",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Закладки на посилання в мережі періодично перевіряються на доступність. Закладки, до яких відсутній доступ, буде наведено тут.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Ви можете поділитися каталогами закладок з іншими користувачами. Усі каталоги, якими поділилися з вами, буде наведено тут.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Одна й та саме закладка може міститися одночасно в різних каталогах. Внесення змін до такої закладки оновить всі її копії. Повторювані закладки наведено тут для зручности.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Вибрано {folders} каталогів та {bookmarks} закладок",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Вибрано %n закладку","Вибрано %n закладки","Вибрано %n закладок","Вибрано %n закладок"],
    "_Selected %n folder_::_Selected %n folders_" : ["Вибрано %n каталог","Вибрано %n каталоги","Вибрано %n каталогів","Вибрано %n каталогів"],
    "Do you really want to delete these items?" : "Дійсно вилучити ці об'єкти?",
    "Open all selected" : "Відкрити всі вибрані",
    "Move selection" : "Перемістити вибране",
    "Edit tags of selection" : "Редагувати мітки вибраного",
    "Delete selection" : "Прибрати виділення",
    "Select all" : "Вибрати все",
    "Cancel selection" : "Скасувати вибір",
    "Sort by created date" : "Впорядкувати за датою створення",
    "Sort by last modified" : "Впорядкувати за останніми змінами",
    "Sort by title" : "Впорядкувати за назвою",
    "Sort by click count" : "Впорядкувати за кількістю переходів",
    "Sort by manual order" : "Впорядкувати вручну",
    "Sort by URL" : "Впорядкувати за посиланнями",
    "RSS feed copied" : "Стрічку RSS скопійовано",
    "Trash Bin" : "Кошик",
    "Go back" : "Повернутися назад",
    "Share folder" : "Спільний доступ до каталогу",
    "Open folder details" : "Показати деталі каталогу",
    "Select one or more tags" : "Виберіть одну або кілька міток",
    "New" : "Створити",
    "New bookmark" : "Нова закладка",
    "New folder" : "Новий каталог",
    "Change to grid view" : "Подання сіткою",
    "Change to list view" : "Подання списком",
    "Copy RSS Feed of current view" : "Копіювати стрічку RSS поточного подання",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Стрічка RSS вимагає авторизації з вашим обліковим записом у хмарі Nextcloud",
    "Search" : "Пошук",
    "Empty trash bin" : "Очистити кошик",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Додати %n закладку до нового каталогу","Додати %n закладки до нового каталогу","Додати %n закладок до нового каталогу","Додати %n закладок до нового каталогу"],
    "Enter a link" : "Зазначте посилання",
    "Enter a title" : "Зазначте заголовок",
    "No bookmarks found" : "Закладки не знайдено",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} каталогів та {bookmarks} закладок",
    "_%n bookmark_::_%n bookmarks_" : ["%n закладка","%n закладки","%n закладок","%n закладок"],
    "_%n folder_::_%n folders_" : ["%n каталог","%n каталоги","%n каталогів","%n каталогів"],
    "Welcome to Bookmarks" : "Вітаємо у застосунку \"Закладки\"",
    "Add a bookmark" : "Додати закладку",
    "Import bookmarks" : "Імпорт закладок",
    "Sync with your browser" : "Синхронізувати з бравзером",
    "Do you really want to permanently delete this folder?" : "Дійсно вилучити цей каталог без можливості відновлення?",
    "Select folder" : "Виберіть каталог",
    "Enter folder title" : "Зазначте назву каталогу",
    "Shared by {user}" : "{user} надав(-ла) доступ",
    "Rename folder" : "Перейменувати каталог",
    "Move folder" : "Перемістити каталог",
    "Put folder into trashbin" : "Вилучити каталог",
    "Restore folder" : "Відновити каталог",
    "Delete folder permanently" : "Вилучити каталог назавжди",
    "Choose folder" : "Виберіть каталог",
    "Submit" : "Гаразд",
    "Cancel" : "Скасувати",
    "Deleting bookmarks" : "Вилучення закладок",
    "Deleting selection" : "Вилучення вибраного",
    "Importing bookmarks" : "Відбувається імпорт закладок",
    "Moving selection" : "Переміщення вибраного",
    "Adding selection to folders" : "Додавання вибору до каталогів",
    "Emptying trashbin" : "Очистка кошика",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Переміщення %n каталогу та закладок","Переміщення %n каталогів та закладок","Переміщення %n каталогів та закладок","Переміщення %n каталогів та закладок"],
    "_Moving %n folder_::_Moving %n folders_" : ["Переміщення %n каталогу","Переміщення %n каталогів","Переміщення %n каталогів","Переміщення %n каталогів"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Переміщення %n закладки","Переміщення %n закладок","Переміщення %n закладок","Переміщення %n закладок"],
    "All bookmarks" : "Усі закладки",
    "Recent" : "Останні",
    "Shared with you" : "Спільні",
    "Files" : "Файли",
    "Duplicates" : "Повторювані",
    "Broken links" : "Загублені посилання",
    "New tag" : "Нова мітка",
    "Search tags" : "Шукати мітки",
    "Delete" : "Вилучити",
    "Untagged" : "Без мітки",
    "{used} bookmarks of {available} available" : "{used} із {available} закладок доступно",
    "Bookmarks Settings" : "Налаштування",
    "No bookmarked files" : "Відсутні закладки з файлами",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Закладки на файли, такі як світлини або файли PDF, буде автоматично збережено до ваших файлів у хмарі Nextcloud. Таким чином ви зможете завжди їх знаходити, навіть якщо посилання будуть недоступні.",
    "Nothing found" : "Нічого не знайдено",
    "Your search yielded no results in the current folder." : "Нічого не знайдено в поточному каталозі.",
    "No broken links" : "Відсутні загублені посилання",
    "No shared folders" : "З вами ще ніхто не поділився каталогами",
    "No duplicated bookmarks" : "Відсутні повторювані закладки",
    "No deleted bookmarks" : "Відсутні закладки в кошику",
    "You haven't deleted anything yet." : "Ви поки не перемістили жодної закладки до кошика.",
    "No bookmarks here" : "Тут відсутні закладки",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Додайте закладки вручну або імпортуйте з файлу HTML.",
    "Archive path" : "Шлях до архівних копій",
    "Backup path" : "Шлях до резервних копій",
    "Please select \"Add to home screen\" in your browser menu" : "Виберіть \"Додати на Домівку\" у налаштуваннях бравзера",
    "Bookmarks settings" : "Налаштування",
    "Import/Export" : "Імпорт/експорт",
    "Export bookmarks" : "Експорт закладок",
    "Auto-archiving" : "Архівні копії",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Застосунок \"Закладки\" може автоматично архівувати вміст посилань, які ви поставили у закладки",
    "Enable archiving" : "Увімкнути збереження архівів",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Зазначте шлях до каталогу у Файлах для збереження закладок",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Адміністратор вимкнув доступ до цього застосунку, тому автоматичне архівування наразі недоступне.",
    "Auto-Backup" : "Резервні копії",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Застосунок \"Закладки\" може автоматично створювати щоденні резервні копії ваших закладок, що унеможливить втрату даних під час синхронізації закладок між пристроями.",
    "Enable backups" : "Увімкнути збереження резервних копій",
    "Enter the path of a folder in your Files where backups will be stored." : "Зазначте шлях до каталогу у застосунку Файли для збереження резервних версій.",
    "Client apps" : "Застосунки",
    "Also check out the collection of client apps that integrate with this app: " : "Також перегляньте колекцю клієнтських застосунків, які інтегруються з цим застосунком:",
    "Install web app" : "Вебзастосунки",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Ви можете встановити застосунок на домівці вашого пристрою для швидкого доступу до закладок. Застосунок можна легко прибрати з домівки, якщо буде непотрібний.",
    "Install on home screen" : "Встановити на домівці",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Перетягніть це до закладок бравзера, клацніть для створення закладки вебсторінки",
    "Add to {instanceName}" : "Додати до {instanceName}",
    "Need help?" : "Потрібна допомога?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Якщи ви стикнетеся з проблемами в роботі застосунку \"Закладки\" або маєте пропозиції з удосконалення, просимо контактувати з нами.",
    "Support this project" : "Підтримати",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Моя робота над застосунком \"Закладки\" основана на моделі волонтерської передплати. Якщо ви оцінили її результат, буду вдячний за будь-яку підтримку з вашого боку. Також прош оцінити застосунок у крамниці застосунків Nextcloud. Дякую вам 💙",
    "(Empty title)" : "(Без заголовку)",
    "Title" : "Назва",
    "Link" : "Посилання",
    "Untitled folder" : "Каталог без назви",
    "Root folder" : "Кореневий каталог",
    "Tags" : "Мітки",
    "Select tags and create new ones" : "Виберіть мітку або додайте власну",
    "Notes" : "Примітки",
    "Notes for this bookmark …" : "Додайте примітку до цієї закладки ...",
    "Archived file" : "Архівні файли",
    "Download file" : "Звантажити файл",
    "Open file location" : "Відкрити розташування файлу",
    "Link copied" : "Посилання скопійовано",
    "Owner" : "Власник",
    "Sharing" : "Поділитися",
    "Select a user or group" : "Виберіть користувача або групу",
    "Share link" : "Поділитися посиланням",
    "Reading allowed" : "Дозволено перегляд",
    "Copy RSS feed" : "Копіювати стрічку RSS",
    "Delete link" : "Вилучити посилання",
    "Create public link" : "Створити публічне посилання",
    "Resharing allowed" : "Дозволено передавати у спільний доступ іншим",
    "Editing allowed" : "Редагування дозволено",
    "Allow editing" : "Дозволити редагування",
    "Allow resharing" : "Дозволити передавати у спільний доступ іншим",
    "Remove share" : "Вилучити спільний доступ",
    "Failed to save settings" : "Неможливо зберегти налаштування",
    "Failed to load settings" : "Не вдалося завантажити налаштування",
    "Privacy" : "Конфіденційність",
    "The app will try to access web pages that you add to automatically add information about them." : "Цей застосунок спробує отримати доступ до вебсторінок, які буде додано для автоматичного отримання інформації про них.",
    "Enable accessing and collecting information from the web pages you add" : "Увімкнути доступ та збір інформаці від вебсторінок, які ви додаєте",
    "Performance" : "Продуктивність",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "У разі налаштування для багатьох користувачів рекомендується обмежити максимальну кількість закладок для кожного з користувачів.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Максимально припустиме число закладок для одного користувача (0 для зняття обмежень, типове значення)",
    "Previews" : "Попередній перегляд",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Щоби показувати справжні скриншоти закладок вебсайтів, застосунок може використовувати треті послуги для створення попередніх переглядів.",
    "You can either sign up for free at screeenly.com or setup your own server." : "Ви можете безкоштовно передплатити послуги на сайті screenly.com або налаштувати власний сервер.",
    "Screeenly API key" : "Ключ API Screeenly",
    "ScreenshotMachine API key" : "Ключ API ScreenshotMachine",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Увійдіть з одним з постачальників послуг API скриншотів, зазначте посилання на API. Використайте змінну {url} як заповнювач посилання до скриншоту.  API має повертати тільки зображення.",
    "Generic API URL" : "Загальне посилання API",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Просто встановіть Pageres CLI від Синдра Соргуса на вашому сервері, а застосунок \"Закладки\" сам його ідентифікує. Також можна додати змінні оточення ENV, які вестимуть до Pageres, напр., як це зазначено у заповнювачі:",
    "Pageres ENV variables" : "Змінні оточення ENV Pageres",
    "This URL is already bookmarked! Overwrite?" : "Цей URL вже є в закладках! Перезаписати?",
    "Enter bookmark title" : "Зазначте назву закладки",
    "Enter bookmark URL" : "Зазначте посилання закладки",
    "Folder" : "Каталог",
    "Root Folder" : "Кореневий каталог",
    "Save" : "Зберегти",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Доступ до мережі типово вимкнено. Перейдіть до адміністративних налаштувань застосунку \"Закладки\" та дозвольте отримання попереднього перегляду та значків сайтів.",
    "What's new?" : "Що нового?",
    "Leave a rating on the Nextcloud App Store" : "Оцініть застосунок у крамниці застосунків Nextcloud",
    "What" : "Що?",
    "Failed to count unavailable bookmarks" : "Не вдалося визначити кількість недоступних закладок",
    "Failed to count archived bookmarks" : "Не вдалося визначити кількість архівних закладок",
    "Failed to count duplicated bookmarks" : "Не вдалося визначити кількість повторюваних закладок",
    "Failed to load bookmark" : "Не вдалося завантажити закладку",
    "Failed to find existing bookmark" : "Не вдалося знайти наявну закладку",
    "Failed to create bookmark" : "Не вдалося створити закладку",
    "Failed to save bookmark" : "Не вдалося зберегти закладку",
    "Failed to move bookmark" : "Не вдалося перемістити закладку",
    "Failed to copy bookmark" : "Не вдалося скопіювати закладку",
    "Failed to delete bookmark" : "Не вдалося вилучити закладку",
    "Failed to rename tag" : "Не вдалося перейменувати мітку",
    "Failed to load tags" : "Не вдалося завантажити мітки",
    "Failed to load folders" : "Не вдалося завантажити каталоги",
    "Failed to load deleted folders" : "Не вдалося вилучені каталоги",
    "Failed to load deleted bookmarks" : "Не вдалося вилучені закладки",
    "Failed to delete folder" : "Не вдалося вилучити каталог",
    "Failed to move folder" : "Не вдалося перемістити каталог",
    "Failed to create folder" : "Не вдалося створити каталог",
    "Failed to fetch bookmarks." : "Не вдалося отримати закладки.",
    "Failed to store setting" : "Не вдалося зберегти налаштування",
    "Failed to load setting {key}" : "Не вдалося отримати налаштування {key}",
    "Failed to update share {shareId}" : "Не вдалося оновити спільний ресурс {shareId}",
    "Failed to delete share {shareId}" : "Не вдалося вилучити спільний ресурс {shareId}",
    "Create bookmarks for mentioned links" : "Створити закладки для згаданих посилань",
    "No links found in this message" : "Не знайдено посилання у повідомленнях",
    "Bookmarks feed" : "Стрічка закладок"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
